@@ -4,15 +4,24 @@ from . import (
     ClosedEvent,
     CommentDeletedEvent,
     CrossReferencedEvent,
+    DemilestonedEvent,
     IssueComment,
+    IssueTypeAddedEvent,
+    IssueTypeChangedEvent,
     LabeledEvent,
     MentionedEvent,
+    MilestonedEvent,
     MovedColumnsInProjectEvent,
+    ParentIssueAddedEvent,
+    ParentIssueRemovedEvent,
     PinnedEvent,
     ReferencedEvent,
     RenamedTitleEvent,
     ReopenedEvent,
+    SubIssueAddedEvent,
+    SubIssueRemovedEvent,
     SubscribedEvent,
+    TransferredEvent,
     UnassignedEvent,
     UnlabeledEvent,
     UnsubscribedEvent,
